@@ -21,12 +21,12 @@ class SIGMOID:
     return np.maximum(X,0)
 
   def d(self, Y):
-    # result = self.predict(Y)*(1-self.predict(Y))
-    # return result
-
-    result = np.ones(Y.shape)
+    result = self.predict(Y)*(1-self.predict(Y))
     return result
 
+    # result = np.ones(Y.shape)
+    # return result
+
   def __str__(self):
     return 'SIGMOID'
 
