@@ -1,6 +1,6 @@
 import numpy as np
 
-def train_test_split(self, x, y, validation_split, is_shuffle):
+def train_test_split(x, y, validation_split, is_shuffle):
     unit = int(x.shape[0] * validation_split)
     shuffle = np.arange(x.shape[0])
     if is_shuffle:
